﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Blockbuster
{
    public partial class Blockbuster : Form
    {
        private IList<Block> blocks;
        private SelectedBlock selectedBlock;

        public Blockbuster()
        {
            InitializeComponent();

            blocks = new List<Block>();

            Paint += (sender, e) =>
                {
                    foreach (Block block in blocks)
                    {
                        e.Graphics.FillRectangle(new SolidBrush(block.Colour), block.Position);
                    }
                };

            MouseDown += (sender, e) =>
                {
                    for (int i = (blocks.Count - 1); i >= 0; i--)
                    {
                        if (blocks[i].Position.Contains(e.Location))
                        {
                            selectedBlock = new SelectedBlock(blocks[i], e.Location);
                            break;
                        }
                    }
                };

            MouseUp += (sender, e) =>
                {
                    selectedBlock = null;
                };

            MouseMove += (sender, e) =>
                {
                    if (selectedBlock != null)
                    {
                        selectedBlock.Update(e.Location);

                        Invalidate();
                    }
                };
        }

        private void blockButton_Click(object sender, EventArgs e)
        {
            ColorDialog diag = new ColorDialog();

            if (diag.ShowDialog() == DialogResult.OK)
            {
                blocks.Add(new Block(diag.Color));

                Invalidate();
            }
        }
    }
}
